//environment
PyDoc_STRVAR(environment_doc,
	"Rendering environment such as light source and fog"
);

PyDoc_STRVAR(getDirectionalLampIntensity_doc,
	"Get intensity value of directional lamp\n"\
	"\n"\
	"intensity = environment.getDirectionalLampIntensity(index)\n"\
	"\n"\
	"Parameters\n"\
	"----------\n"\
	"    index : int\n"\
	"        light index no (0 or 1 or 2)"
	"Returns\n"\
	"-------\n"\
	"    intensity : float\n"\
	"        intensity value of directional lamp"
);

PyDoc_STRVAR(setDirectionalLampIntensity_doc,
	"Set intensity value of directional lamp\n"\
	"\n"\
	"environment.getDirectionalLampIntensity(index, value)\n"\
	"\n"\
	"Parameters\n"\
	"----------\n"\
	"    index : int\n"\
	"        light index no (0 or 1 or 2)"
	"    value : float\n"\
	"        intensity value of directional lamp"
);

PyDoc_STRVAR(getDirectionalLampColor_doc,
	""
);
PyDoc_STRVAR(setDirectionalLampColor_doc,
	""
);
PyDoc_STRVAR(getDirectionalLampDirection_doc,
	""
);
PyDoc_STRVAR(setDirectionalLampDirection_doc,
	""
);
PyDoc_STRVAR(getPointLampRange_doc,
	""
);
PyDoc_STRVAR(setPointLampRange_doc,
	""
);
PyDoc_STRVAR(getPointLampIntensity_doc,
	""
);
PyDoc_STRVAR(setPointLampIntensity_doc,
	""
);
PyDoc_STRVAR(getPointLampColor_doc,
	""
);
PyDoc_STRVAR(setPointLampColor_doc,
	""
);
PyDoc_STRVAR(getPointLampPosition_doc,
	""
);
PyDoc_STRVAR(setPointLampPosition_doc,
	""
);

PyDoc_STRVAR(ambientColor_doc,
	""
);
PyDoc_STRVAR(groundColor_doc,
	""
);
PyDoc_STRVAR(ambientDirection_doc,
	""
);
PyDoc_STRVAR(distanceFogNear_doc,
	""
);
PyDoc_STRVAR(distanceFogFar_doc,
	""
);
PyDoc_STRVAR(distanceFogAlpha_doc,
	""
);
PyDoc_STRVAR(distanceFogColor_doc,
	""
);

